@@ -10,14 +10,24 @@ use Bread::Board::Container;
 use Bread::Board::Container::Parameterized;
 use Bread::Board::Dependency;
 use Bread::Board::LifeCycle::Singleton;
+use Bread::Board::Service::Inferred;
 
 use Moose::Exporter;
 Moose::Exporter->setup_import_methods(
-    as_is => [qw( as container depends_on service wire_names include )],
+    as_is => [qw[
+        as
+        container
+        depends_on
+        service
+        wire_names
+        include
+        typemap
+        infer
+    ]],
 );
 
 our $AUTHORITY = 'cpan:STEVAN';
-our $VERSION   = '0.14';
+our $VERSION   = '0.15';
 
 sub as (&) { $_[0] }
 
@@ -86,7 +96,7 @@ sub service ($@) {
     elsif (scalar(@_) % 2 == 0) {
         my %params = @_;
         my $type   = $params{service_type} || (exists $params{block} ? 'Block' : 'Constructor');
-        $s =  "Bread::Board::${type}Injection"->new(name => $name, %params);
+        $s = "Bread::Board::${type}Injection"->new(name => $name, %params);
     }
     else {
         confess "I don't understand @_";
@@ -94,6 +104,40 @@ sub service ($@) {
     $CC->add_service($s);
 }
 
+sub typemap ($@) {
+    my $type = shift;
+
+    (scalar @_ == 1)
+        || confess "Too many (or too few) arguments to typemap";
+
+    my $service;
+    if (blessed $_[0]) {
+        if ($_[0]->does('Bread::Board::Service')) {
+            $service = $_[0];
+        }
+        elsif ($_[0]->isa('Bread::Board::Service::Inferred')) {
+            $service = $_[0]->infer_service( $type );
+        }
+        else {
+            confess "No idea what to do with a " . $_[0];
+        }
+    }
+    else {
+        $service = $CC->fetch( $_[0] );
+    }
+
+    $CC->add_type_mapping_for( $type, $service );
+}
+
+sub infer {
+    my %params = @_;
+    Bread::Board::Service::Inferred->new(
+        current_container => $CC,
+        service_args      => \%params,
+        infer_params      => 1,
+    );
+}
+
 sub wire_names { +{ map { $_ => depends_on($_) } @_ }; }
 
 sub depends_on ($) {
@@ -222,12 +266,16 @@ Want to know more? See the L<Bread::Board::Manual>.
 
 =item I<as (&body)>
 
-=item I<service ($name, $literal|%service_description)>
+=item I<service ($name, $literal | %service_description)>
 
-=item I<depends_on ($service_name)>
+=item I<depends_on ($service_path)>
 
 =item I<wire_names (@service_names)>
 
+=item I<typemap ($type, $service | $service_path)>
+
+=item I<infer (?%hints)>
+
 =item I<include ($file)>
 
 =back
