@@ -7,7 +7,7 @@ use Bread::Board::Types;
 use Bread::Board::Service::Deferred;
 use Bread::Board::Service::Deferred::Thunk;
 
-our $VERSION   = '0.14';
+our $VERSION   = '0.15';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Bread::Board::Service';
@@ -38,6 +38,8 @@ around 'init_params' => sub {
     +{ %{ $self->$next() }, $self->resolve_dependencies }
 };
 
+after 'get' => sub { (shift)->clear_params };
+
 sub resolve_dependencies {
     my $self = shift;
     my %deps;
@@ -62,7 +64,7 @@ sub resolve_dependencies {
                 # since we can't pass in parameters here,
                 # we return a deferred thunk and you can do
                 # with it what you will.
-                if ( $service->does('Bread::Board::Service::WithParameters') && $service->has_parameters ) {
+                if ( $service->does('Bread::Board::Service::WithParameters') && $service->has_required_parameters ) {
                     $deps{$key} = Bread::Board::Service::Deferred::Thunk->new(
                         thunk => sub {
                             my %params = @_;
